#include <chronoptics/tof/csf_writer.hpp>
#include <chronoptics/tof/kea_camera.hpp>
#include <iostream>

namespace tof = chronoptics::tof;

int main() {
  /* Number of frames to capture */
  const int numFrames = 100;

  /* Number of frames to drop before capturing */
  const int dropFrames = 100;

  /* Filename to save to */
  const char* filename = "frames.csf";

  /* Serial number of the camera to connect to. If this is empty, the
     first camera that is found will be connected to */
  const char* serial = "2020004";

  /* Frame types to capture */
  const std::vector<tof::FrameType> types = {tof::FrameType::RAW};

  /* Initialise a KeaCamera with all of the filters disabled, and use
     the given configuration */
  tof::KeaCamera cam(tof::ProcessingConfig{}, serial);
  auto config = cam.get_camera_config();

  config.reset();

  config.set_phase_shifts(0, {0.0, 0.25, 0.5, 0.75});
  config.set_integration_time(0, {400, 400, 400, 400});
  config.set_modulation_frequency(0, 50);

  cam.set_camera_config(config);

  tof::select_streams(cam, types);

  tof::CsfWriter writer = tof::create_csf_writer_camera(filename, cam);

  cam.start();

  /* Drop frames */
  for (int i = 0; i < dropFrames; i++) {
    cam.get_frames();
  }

  std::cout << "Frames dropped" << std::endl;

  /* Capture frames */
  for (int i = 0; i < numFrames; i++) {
    std::vector<tof::Data> frames = cam.get_frames();

    for (tof::Data& frame : frames) {
      writer.write_frame(frame);
    }
  }

  std::cout << "Frames captured" << std::endl;

  cam.stop();
}
